Enums
- Install
Hook Result - Outcome of
install_pre_commit_hook. Both variants are “no error” — the caller decides whetherAlreadyExiststriggers a non-zero exit.
Functions
- install_
pre_ commit_ hook - Install a
pre-commitgit hook underrepo_root/.git/hooks/. - npmrc_
registry - Parse
registry=...from a .npmrc-style file. Supports: - rewrite_
lockfile - rewrite_
lockfile_ to_ local - Read the lockfile, rewrite any
resolvedURL whose host is exactlyregistry.npmjs.orgto point atlocal_url, write it back, and return the number of URLs changed. - rewrite_
lockfile_ to_ public - Read the lockfile, rewrite any
resolvedURL whose host is local (seeis_local_host) to point athttps://registry.npmjs.org, write it back, and return the number of URLs changed. - update_
urls - update_
urls_ from_ config - update_
urls_ in_ package_ lock